==> rapid_widgets_library-0.2.32.tar.gz: lib/custom-webDrawer.dart <==
import 'package:flutter/cupertino.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:flutter/material.dart';

class NavigationDrawerWEB extends StatefulWidget {
  final DrawerParameters drawerParameters;
  NavigationDrawerWEB({this.drawerParameters});

  @override
  _NavigationDrawerState createState() => _NavigationDrawerState();
}

class _NavigationDrawerState extends State<NavigationDrawerWEB> {

  Widget buildHeader(){
    return (widget.drawerParameters.phone!='null'||widget.drawerParameters.email!='null'||widget.drawerParameters.name!='null'||widget.drawerParameters.urlImage!='null')?
    Container(
      padding: EdgeInsets.symmetric(vertical: 10),
      child: (widget.drawerParameters.urlImage!='null')?
      TranslateOnHover(child: CircleAvatar(radius: 20, backgroundImage: NetworkImage(widget.drawerParameters.urlImage))):SizedBox(width: 20,),
      /*Column(

        children: [
          Padding(
            padding: const EdgeInsets.only(left: 200, bottom: 10),
            child: GestureDetector(
                onTap: (){
                  Navigator.pop(context);
                },
                child: Icon(Icons.clear,color: Colors.black,)),
          ),

          SizedBox(width: 20),
          (widget.drawerParameters.urlImage!='null')?CircleAvatar(radius: 20, backgroundImage: NetworkImage(widget.drawerParameters.urlImage)):SizedBox(width: 20,),
          SizedBox(width: 20),
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              (widget.drawerParameters.name!='null')? Text(widget.drawerParameters.name, style: TextStyle(fontSize: 14, color: Colors.black)) :SizedBox.shrink(),
              (widget.drawerParameters.name!='null')?const SizedBox(height: 2):SizedBox.shrink(),
              (widget.drawerParameters.email!='null')?Text(widget.drawerParameters.email, style: TextStyle(fontSize: 12, color: Colors.black), overflow: TextOverflow.clip,):SizedBox.shrink(),
              (widget.drawerParameters.email!='null')?const SizedBox(height: 2):SizedBox.shrink(),
              (widget.drawerParameters.phone!='null')?Text(widget.drawerParameters.phone, style: TextStyle(fontSize: 12, color: Colors.black),):SizedBox.shrink(),
            ],
          ),
          const SizedBox(height: 10),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 30),
            child: Divider(color: Colors.grey, thickness: 0.5),
          ),
        ],
      )*/
    ):
    SizedBox(
      height: 20,
      child: Padding(
        padding: const EdgeInsets.only(left: 210,top: 5),
        child: GestureDetector(
            onTap: (){
              Navigator.pop(context);
            },
            child: Icon(Icons.clear,color: Colors.black,)),
      ) ,
    );
  }

  Widget buildMenuItem({
    String text,
    IconData icon,
    Color  iconTextColor
  }) {
    final hoverColor = Colors.grey[300];
    return (text!='null' || icon!=null)?Padding(
      padding: const EdgeInsets.symmetric(horizontal: 20),
      child: (icon!=null)?ListTile(
        leading: Icon(icon, color: iconTextColor??Colors.black),
        title: (text!='null')?Text(text, style: TextStyle(color: iconTextColor??Colors.black)):SizedBox.shrink(),
        hoverColor: hoverColor,
        onTap: (){},
      ):ListTile(
        title: (text!='null')?Text(text, style: TextStyle(color: iconTextColor??Colors.black)):SizedBox.shrink(),
        hoverColor: hoverColor,
        onTap: (){},
      ),
    ):SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {

    return Container(
      child: Material(
        color: widget.drawerParameters.drawerColor,
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceAround,
          children: [
            Padding(
              padding:  EdgeInsets.only(left: 10),
              child: buildHeader(),
            ),

            for(int i =0; i<widget.drawerParameters.items.length;i++)
              for(var key in widget.drawerParameters.items[i].keys)
                if(widget.drawerParameters.items[i].keys!='null' && widget.drawerParameters.items[i][key]!=null )
                  TranslateOnHover(child: Row(
                    children: [
                      (widget.drawerParameters.items[i][key]!=null)?Icon(widget.drawerParameters.items[i][key],color: widget.drawerParameters.iconTextColor,):SizedBox.shrink(),
                      (widget.drawerParameters.items[i][key]!=null)?SizedBox(width: 4,):SizedBox.shrink(),
                      (key!='null')?Text(key,style: TextStyle(color: widget.drawerParameters.iconTextColor),):SizedBox.shrink(),
                    ],
                  )),
            /*(widget.drawerParameters.items!=null)?Container(
              child: Column(
                children: [
                  const SizedBox(height: 12),
                  for(int i =0; i<widget.drawerParameters.items.length;i++)
                    for(var key in widget.drawerParameters.items[i].keys)
                      buildMenuItem(
                          text: key,
                          icon: widget.drawerParameters.items[i][key],
                          iconTextColor: widget.drawerParameters.iconTextColor
                      ),
                  SizedBox(height: 12),
                ],
              ),
            ):SizedBox.shrink(),*/
          ],
        ),
      ),
    );
  }
}





class TranslateOnHover extends StatefulWidget {
  final Widget child;
  TranslateOnHover({ this.child});

  @override
  _TranslateOnHoverState createState() => _TranslateOnHoverState();
}

class _TranslateOnHoverState extends State<TranslateOnHover> {
  final nonHoverTransform = Matrix4.identity();
  final hoverTransform = Matrix4.identity()..translate(0, -5, 0)..scale(1.1);

  bool _hovering = false;

  @override
  Widget build(BuildContext context) {
    return MouseRegion(
      onEnter: (e) => _mouseEnter(true),
      onExit: (e) => _mouseEnter(false),
      child: AnimatedContainer(
        duration: const Duration(milliseconds: 200),
        child: widget.child,
        transform: _hovering ? hoverTransform : nonHoverTransform,
      ),
    );
  }

  void _mouseEnter(bool hovering) {
    setState(() {
      _hovering = hovering;
    });
  }
}

==> rapid_widgets_library-0.2.33.tar.gz: lib/custom-webDrawer.dart <==
import 'package:flutter/cupertino.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:flutter/material.dart';

class NavigationDrawerWEB extends StatefulWidget {
  final DrawerParameters drawerParameters;
  NavigationDrawerWEB({this.drawerParameters});

  @override
  _NavigationDrawerState createState() => _NavigationDrawerState();
}

class _NavigationDrawerState extends State<NavigationDrawerWEB> {

  Widget buildHeader(){
    return (widget.drawerParameters.urlImage!='null')?
    Container(
      padding: EdgeInsets.symmetric(vertical: 10),
      child: CircleAvatar(radius: 20, backgroundImage: NetworkImage(widget.drawerParameters.urlImage))
    ):
    SizedBox.shrink();
  }

  Widget buildMenuItem({
    String text,
    IconData icon,
    Color  iconTextColor
  }) {
    final hoverColor = Colors.grey[300];
    return (text!='null' || icon!=null)?
    Padding(
      padding: const EdgeInsets.symmetric(horizontal: 20),
      child: (icon!=null)?
      ListTile(
        leading: Icon(icon, color: iconTextColor??Colors.black),
        title: (text!='null')?Text(text, style: TextStyle(color: iconTextColor??Colors.black)):SizedBox.shrink(),
        hoverColor: hoverColor,
        onTap: (){},
      ):ListTile(
        title: (text!='null')?Text(text, style: TextStyle(color: iconTextColor??Colors.black)):SizedBox.shrink(),
        hoverColor: hoverColor,
        onTap: (){},
      ),
    ):SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {

    return Container(
      child: Material(
        color: widget.drawerParameters.drawerColor,
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceAround,
          children: [
            Padding(
              padding:  EdgeInsets.only(left: 10),
              child: buildHeader(),
            ),

            for(int i =0; i<widget.drawerParameters.items.length;i++)
              for(var key in widget.drawerParameters.items[i].keys)

                if(key!='null'|| widget.drawerParameters.items[i][key]!=null)
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: TranslateOnHover(
                icon: widget.drawerParameters.items[i][key],
                text:key,
                iconTextColor: widget.drawerParameters.iconTextColor,
              ),
            )
          ],
        ),
      ),
    );
  }
}






class TranslateOnHover extends StatefulWidget {
  final Widget child;
   final String text;
   final  IconData icon;
   final Color  iconTextColor;
  TranslateOnHover({ this.child,
    this.iconTextColor,
    this.icon,
    this.text
  });

  @override
  _TranslateOnHoverState createState() => _TranslateOnHoverState();
}

class _TranslateOnHoverState extends State<TranslateOnHover> {
  final nonHoverTransform = Matrix4.identity();
  final hoverTransform = Matrix4.identity()..translate(0, -5, 0)..scale(1.1);

  bool _hovering = false;

  @override
  Widget build(BuildContext context) {
    return MouseRegion(
      onEnter: (e) => _mouseEnter(true),
      onExit: (e) => _mouseEnter(false),
      child: AnimatedContainer(
        duration: const Duration(milliseconds: 200),
        child:
        (widget.icon!=null)?
        Row(
          children: [
            (widget.icon!=null)?Icon(widget.icon,color: widget.iconTextColor??Colors.black,):SizedBox.shrink(),
              (widget.icon!=null)?SizedBox(width: 4,):SizedBox.shrink(),
                (widget.text!='null')?Text(widget.text,style: TextStyle(color: widget.iconTextColor??Colors.black),):SizedBox()
          ],
        ):Row(
          children: [
            (widget.text!='null')?Text(widget.text,style: TextStyle(color: widget.iconTextColor??Colors.black),):SizedBox()
          ],
        ),
           /* :SizedBox.shrink(),*/

        transform: _hovering ? hoverTransform : nonHoverTransform,
      )
    );
  }

  void _mouseEnter(bool hovering) {
    setState(() {
      _hovering = hovering;
    });
  }
}
